Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(718)

Unified Diff: chrome/browser/cocoa/toolbar_controller.h

Issue 482006: Make a shared app menu model and update win and mac to use it. Remove the NSM... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 11 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/cocoa/toolbar_controller.h
===================================================================
--- chrome/browser/cocoa/toolbar_controller.h (revision 34553)
+++ chrome/browser/cocoa/toolbar_controller.h (working copy)
@@ -14,6 +14,7 @@
#import "chrome/browser/cocoa/view_resizer.h"
#include "chrome/common/pref_member.h"
+class AppMenuModel;
@class AutocompleteTextField;
@class AutocompleteTextFieldEditor;
@class BackForwardMenuController;
@@ -56,11 +57,14 @@
scoped_nsobject<BrowserActionsController> browserActionsController_;
// Lazily-instantiated model, controller, and delegate for the menu on the
// page button. If it's visible, these will be non-null, but they are not
// reaped when the button is hidden once it is initially shown.
scoped_ptr<PageMenuModel> pageMenuModel_;
scoped_nsobject<MenuController> pageMenuController_;
- scoped_ptr<ToolbarControllerInternal::MenuDelegate> pageMenuDelegate_;
+ scoped_ptr<ToolbarControllerInternal::MenuDelegate> menuDelegate_;
+ scoped_ptr<AppMenuModel> appMenuModel_;
+ scoped_nsobject<MenuController> appMenuController_;
// Used for monitoring the optional toolbar button prefs.
scoped_ptr<ToolbarControllerInternal::PrefObserverBridge> prefObserver_;
« no previous file with comments | « chrome/browser/autocomplete/autocomplete_edit_view_win.cc ('k') | chrome/browser/cocoa/toolbar_controller.mm » ('j') | no next file with comments »
@@ -56,11 +57,14 @@
scoped_nsobject<BrowserActionsController> browserActionsController_;
// Lazily-instantiated model, controller, and delegate for the menu on the
- // page button. If it's visible, these will be non-null, but they are not
- // reaped when the button is hidden once it is initially shown.
+ // page and wrench buttons. The wrench menu is also called the "app menu". If
+ // it's visible, these will be non-null, but they are not reaped when the
+ // button is hidden once it is initially shown.
scoped_ptr<PageMenuModel> pageMenuModel_;
scoped_nsobject<MenuController> pageMenuController_;

Powered by Google App Engine
This is Rietveld 408576698